--[[
	Global BaleCounter for FS17
	
	Author: Eagle355th
	Date: 11.4.2016
]]--
--[[0.0.253]]--
--[[0.045525]]

BaleCounter = {};

local bc_directory = g_currentModDirectory;

function BaleCounter.prerequisitesPresent(specializations)
	return SpecializationUtil.hasSpecialization(Baler, specializations);
end;


function BaleCounter:load(xmlFile)
	self.currentBales = 0;
	self.totalBales = 0;
	
	self.xPos = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.BaleCounter#posX"), 0.8);
	self.yPos = Utils.getNoNil(getXMLFloat(self.xmlFile, "vehicle.BaleCounter#posY"), 0.203);

	self.hud = Overlay:new("BaleCounter", Utils.getFilename("BaleCounter_hud.dds", bc_directory), self.xPos, self.yPos, 0.175, 0.035525);
	
	self.dirtyFlag = self:getNextDirtyFlag();
	self.isDirty = true;
end;

function BaleCounter:delete()
end;

function BaleCounter.dropBale(self, baleIndex)
	if self.currentBales ~= nil and self.totalBales ~= nil then
		self.currentBales = self.currentBales + 1;
		self.totalBales   = self.totalBales + 1;
		self.isDirty      = true;
	end;
end;

function BaleCounter:mouseEvent(posX, posY, isDown, isUp, button)
end;

function BaleCounter:keyEvent(unicode, sym, modifier, isDown)
end;

function BaleCounter:update(dt)
	if self.currentBales > 0 then
		if InputBinding.hasEvent(InputBinding.RESET) then
			self.currentBales = 0;
			self.isDirty      = true;
		end;
	end;
end;

function BaleCounter:updateTick(dt)
	if self.isDirty then
		self:raiseDirtyFlags(self.dirtyFlag);
		self.isDirty = false;
	end;
end;

function BaleCounter:draw()
	local x = self.xPos + 0.0;
	local y = self.yPos + 0.0025;
	
	self.hud:render();
	if self.currentBales > 0 then
		g_currentMission:addHelpButtonText(g_i18n:getText("RESET"), InputBinding.RESET);
	end;
	setTextAlignment(RenderText.ALIGN_RIGHT);

	
	setTextColor(1, 1, 1, 1);
    renderText(x + 0.073, y + 0.008, 0.018, tostring(self.currentBales));
	renderText(x + 0.156, y + 0.008, 0.018, tostring(self.totalBales));
	
end;

function BaleCounter:readStream(streamId, connection)
    self.currentBales = streamReadInt32(streamId);
    self.totalBales = streamReadInt32(streamId);
end;

function BaleCounter:writeStream(streamId, connection)
    streamWriteInt32(streamId, self.currentBales);
    streamWriteInt32(streamId, self.totalBales);
end;

function BaleCounter:readUpdateStream(streamId, timestamp, connection)
end;

function BaleCounter:writeUpdateStream(streamId, connection, dirtyMask)
end;

function BaleCounter:mouseEvent(posX, posY, isDown, isUp, button)
end;

function BaleCounter:keyEvent(unicode, sym, modifier, isDown)
end;

function BaleCounter:postLoad(savegame)
	if savegame ~= nil and not savegame.resetVehicles then
		self.totalBales = Utils.getNoNil(getXMLInt(savegame.xmlFile, savegame.key.."#totalBales"), 0);
	
	end;

	return BaseMission.VEHICLE_LOAD_OK;
end;

function BaleCounter:getSaveAttributesAndNodes(nodeIdent)
	local attributes = 'totalBales="'..tostring(self.totalBales)..'" currentBales="'..tostring(self.currentBales)..'"';
	local nodes = nil;
	
	return attributes, nodes;
end;

Baler.dropBale = Utils.appendedFunction(BaleCounter.dropBale, Baler.dropBale);